multidim.covertree.CoverTree
============================

.. currentmodule:: multidim.covertree

.. autoclass:: CoverTree

   

      .. autosummary::
         :toctree:
      
         CoverTree.make_edges
         CoverTree.next
         CoverTree.plot
         CoverTree.plot_tree
         CoverTree.reset
         CoverTree.sparse_complex



   

